@@ -82,7 +82,6 @@ class ProxyContext:
     tcp_timeout = 0
     verbose = False
     ignore_ssl_validate = False
-    reconnects = 0
     ssh_user = ""
     additional_args = None
     disable_prompts = False
@@ -371,7 +370,7 @@ def create_client(ctx: click.Context, opts: ProxyContext) -> CumulocityClient:
 
             success = True
             break
-        except CumulocityMissingTFAToken as ex:
+        except CumulocityMissingTFAToken:
             client.tfacode = click.prompt(
                 text="Enter your Cumulocity TFA-Token", hide_input=False
             )
@@ -628,7 +627,6 @@ def start_proxy(
         "token": opts.token,
         "ignore_ssl_validate": opts.ignore_ssl_validate,
         "ping_interval": opts.ping_interval,
-        "max_retries": 2,
     }
 
     tcp_server = None
